==> jc-1.4.0.tar.gz: javax/security/sasl/Sasl.h <==
// public class javax.security.sasl.Sasl

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 41e7fbf07d5418ae javax_security_sasl_Sasl

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_sasl_Sasl_H_
#define _JC_javax_security_sasl_Sasl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Enumeration$object;
struct _jc_java_util_Map$object;
struct _jc_javax_security_auth_callback_CallbackHandler$object;
struct _jc_javax_security_sasl_SaslClient$object;
struct _jc_javax_security_sasl_SaslServer$object;

// Typedefs
typedef struct _jc_javax_security_sasl_Sasl$sub_refs	_jc_javax_security_sasl_Sasl$sub_refs;
typedef struct _jc_javax_security_sasl_Sasl$sub_nonrefs	_jc_javax_security_sasl_Sasl$sub_nonrefs;
typedef struct _jc_javax_security_sasl_Sasl$refs	_jc_javax_security_sasl_Sasl$refs;
typedef struct _jc_javax_security_sasl_Sasl$nonrefs	_jc_javax_security_sasl_Sasl$nonrefs;
typedef struct _jc_javax_security_sasl_Sasl$object	_jc_javax_security_sasl_Sasl$object;

typedef struct _jc_javax_security_sasl_Sasl$fields_struct	_jc_javax_security_sasl_Sasl$fields_struct;
typedef const struct _jc_javax_security_sasl_Sasl$vmethods	_jc_javax_security_sasl_Sasl$vmethods;
typedef const struct _jc_javax_security_sasl_Sasl$vtable	_jc_javax_security_sasl_Sasl$vtable;
typedef const struct _jc_javax_security_sasl_Sasl$vtype	_jc_javax_security_sasl_Sasl$vtype;

// Class fields structure
struct _jc_javax_security_sasl_Sasl$fields_struct {
	struct _jc_java_lang_String$object	*ALIAS;
	struct _jc_java_lang_String$object	*CLIENT__5fFACTORY__5fSVC;
	struct _jc_java_lang_String$object	*MAX__5fBUFFER;
	struct _jc_java_lang_String$object	*POLICY__5fFORWARD__5fSECRECY;
	struct _jc_java_lang_String$object	*POLICY__5fNOACTIVE;
	struct _jc_java_lang_String$object	*POLICY__5fNOANONYMOUS;
	struct _jc_java_lang_String$object	*POLICY__5fNODICTIONARY;
	struct _jc_java_lang_String$object	*POLICY__5fNOPLAINTEXT;
	struct _jc_java_lang_String$object	*POLICY__5fPASS__5fCREDENTIALS;
	struct _jc_java_lang_String$object	*QOP;
	struct _jc_java_lang_String$object	*RAW__5fSEND__5fSIZE;
	struct _jc_java_lang_String$object	*REUSE;
	struct _jc_java_lang_String$object	*SERVER__5fAUTH;
	struct _jc_java_lang_String$object	*SERVER__5fFACTORY__5fSVC;
	struct _jc_java_lang_String$object	*STRENGTH;
};
extern _jc_javax_security_sasl_Sasl$fields_struct _jc_javax_security_sasl_Sasl$class_fields;

// Constructors
extern void _jc_javax_security_sasl_Sasl$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_sasl_Sasl$object *);

// Static methods
extern struct _jc_object *_jc_javax_security_sasl_Sasl$method$createSaslClient$4e16fb9ecadc6e51(_jc_env *, struct _jc_object_array *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_object *);
extern struct _jc_object *_jc_javax_security_sasl_Sasl$method$createSaslServer$0aebf194bdeddd82(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_object *);
extern struct _jc_object *_jc_javax_security_sasl_Sasl$method$getSaslClientFactories$123188e5daf5e6b7(_jc_env *);
extern struct _jc_object *_jc_javax_security_sasl_Sasl$method$getSaslServerFactories$2f151624264f2ee6(_jc_env *);

// Virtual methods structure
struct _jc_javax_security_sasl_Sasl$vmethods {
};

// Vtable
struct _jc_javax_security_sasl_Sasl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_sasl_Sasl$vmethods	javax_security_sasl_Sasl;
};

// Vtype
struct _jc_javax_security_sasl_Sasl$vtype {
	_jc_type			type;
	_jc_javax_security_sasl_Sasl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_sasl_Sasl$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_sasl_Sasl$refs {
    _jc_javax_security_sasl_Sasl$sub_refs	javax_security_sasl_Sasl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_sasl_Sasl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_sasl_Sasl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_sasl_Sasl$sub_nonrefs	javax_security_sasl_Sasl;
};

// Object instance structure
struct _jc_javax_security_sasl_Sasl$object {
	_jc_javax_security_sasl_Sasl$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_sasl_Sasl$vtype	*vtype;
	_jc_javax_security_sasl_Sasl$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_sasl_Sasl$vtype _jc_javax_security_sasl_Sasl$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_sasl_Sasl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_sasl_Sasl$class_object;

#endif	/* _JC_javax_security_sasl_Sasl_H_ */

==> jc-1.4.6.tar.gz: javax/security/sasl/Sasl.h <==
// public class javax.security.sasl.Sasl

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 41e7fbf07d5418ae javax_security_sasl_Sasl

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_security_sasl_Sasl_H_
#define _JC_javax_security_sasl_Sasl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Enumeration$object;
struct _jc_java_util_Map$object;
struct _jc_javax_security_auth_callback_CallbackHandler$object;
struct _jc_javax_security_sasl_SaslClient$object;
struct _jc_javax_security_sasl_SaslServer$object;

// Typedefs
typedef struct _jc_javax_security_sasl_Sasl$sub_refs	_jc_javax_security_sasl_Sasl$sub_refs;
typedef struct _jc_javax_security_sasl_Sasl$sub_nonrefs	_jc_javax_security_sasl_Sasl$sub_nonrefs;
typedef struct _jc_javax_security_sasl_Sasl$refs	_jc_javax_security_sasl_Sasl$refs;
typedef struct _jc_javax_security_sasl_Sasl$nonrefs	_jc_javax_security_sasl_Sasl$nonrefs;
typedef struct _jc_javax_security_sasl_Sasl$object	_jc_javax_security_sasl_Sasl$object;

typedef struct _jc_javax_security_sasl_Sasl$fields_struct	_jc_javax_security_sasl_Sasl$fields_struct;
typedef const struct _jc_javax_security_sasl_Sasl$vmethods	_jc_javax_security_sasl_Sasl$vmethods;
typedef const struct _jc_javax_security_sasl_Sasl$vtable	_jc_javax_security_sasl_Sasl$vtable;
typedef const struct _jc_javax_security_sasl_Sasl$vtype	_jc_javax_security_sasl_Sasl$vtype;

// Class fields structure
struct _jc_javax_security_sasl_Sasl$fields_struct {
	struct _jc_java_lang_String$object	*ALIAS;
	struct _jc_java_lang_String$object	*CLIENT__5fFACTORY__5fSVC;
	struct _jc_java_lang_String$object	*MAX__5fBUFFER;
	struct _jc_java_lang_String$object	*POLICY__5fFORWARD__5fSECRECY;
	struct _jc_java_lang_String$object	*POLICY__5fNOACTIVE;
	struct _jc_java_lang_String$object	*POLICY__5fNOANONYMOUS;
	struct _jc_java_lang_String$object	*POLICY__5fNODICTIONARY;
	struct _jc_java_lang_String$object	*POLICY__5fNOPLAINTEXT;
	struct _jc_java_lang_String$object	*POLICY__5fPASS__5fCREDENTIALS;
	struct _jc_java_lang_String$object	*QOP;
	struct _jc_java_lang_String$object	*RAW__5fSEND__5fSIZE;
	struct _jc_java_lang_String$object	*REUSE;
	struct _jc_java_lang_String$object	*SERVER__5fAUTH;
	struct _jc_java_lang_String$object	*SERVER__5fFACTORY__5fSVC;
	struct _jc_java_lang_String$object	*STRENGTH;
};
extern _jc_javax_security_sasl_Sasl$fields_struct _jc_javax_security_sasl_Sasl$class_fields;

// Constructors
extern void _jc_javax_security_sasl_Sasl$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_security_sasl_Sasl$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_object *_jc_javax_security_sasl_Sasl$method$createSaslClient$4e16fb9ecadc6e51(_jc_env *, struct _jc_object_array *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_security_sasl_Sasl$method$createSaslServer$0aebf194bdeddd82(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_security_sasl_Sasl$method$getSaslClientFactories$123188e5daf5e6b7(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_security_sasl_Sasl$method$getSaslServerFactories$2f151624264f2ee6(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_security_sasl_Sasl$vmethods {
};

// Vtable
struct _jc_javax_security_sasl_Sasl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_security_sasl_Sasl$vmethods	javax_security_sasl_Sasl;
};

// Vtype
struct _jc_javax_security_sasl_Sasl$vtype {
	_jc_type			type;
	_jc_javax_security_sasl_Sasl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_security_sasl_Sasl$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_security_sasl_Sasl$refs {
    _jc_javax_security_sasl_Sasl$sub_refs	javax_security_sasl_Sasl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_security_sasl_Sasl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_security_sasl_Sasl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_security_sasl_Sasl$sub_nonrefs	javax_security_sasl_Sasl;
};

// Object instance structure
struct _jc_javax_security_sasl_Sasl$object {
	_jc_javax_security_sasl_Sasl$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_security_sasl_Sasl$vtype	*vtype;
	_jc_javax_security_sasl_Sasl$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_security_sasl_Sasl$vtype _jc_javax_security_sasl_Sasl$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_security_sasl_Sasl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_security_sasl_Sasl$class_object;

#endif	/* _JC_javax_security_sasl_Sasl_H_ */
